Python bindings for TurboActivate
=================================

.. image:: http://img.shields.io/badge/license-MIT-blue.svg
.. image:: http://img.shields.io/pypi/v/turboactivate.svg

Python bindings for `LimeLM's <http://wyday.com/limelm/>`_ TurboActivate library.

Development status: **stable**.


Installation
------------

::

   pip install turboactivate
